pitchtools.pitch_class_octave_number_string_to_chromatic_pitch_name
===================================================================

.. autofunction:: abjad.tools.pitchtools.pitch_class_octave_number_string_to_chromatic_pitch_name.pitch_class_octave_number_string_to_chromatic_pitch_name
